# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from papermerge_restapi_client.paths.api_pages_move_to_folder_ import Api

from papermerge_restapi_client.paths import PathValues

path = PathValues.API_PAGES_MOVETOFOLDER_