from papermerge_restapi_client.paths.api_tokens_digest_.get import ApiForget
from papermerge_restapi_client.paths.api_tokens_digest_.delete import ApiFordelete


class ApiTokensDigest(
    ApiForget,
    ApiFordelete,
):
    pass
