# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.1
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_preferences_bulk_.post import PreferencesBulkCreate
from papermerge_restapi_client.paths.api_preferences_.get import PreferencesList
from papermerge_restapi_client.paths.api_preferences_id_.patch import PreferencesPartialUpdate
from papermerge_restapi_client.paths.api_preferences_id_.get import PreferencesRetrieve
from papermerge_restapi_client.paths.api_preferences_id_.put import PreferencesUpdate


class PreferencesApi(
    PreferencesBulkCreate,
    PreferencesList,
    PreferencesPartialUpdate,
    PreferencesRetrieve,
    PreferencesUpdate,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
