# coding: utf-8

# flake8: noqa

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.1
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.34"

# import ApiClient
from papermerge_restapi_client.api_client import ApiClient

# import Configuration
from papermerge_restapi_client.configuration import Configuration

# import exceptions
from papermerge_restapi_client.exceptions import OpenApiException
from papermerge_restapi_client.exceptions import ApiAttributeError
from papermerge_restapi_client.exceptions import ApiTypeError
from papermerge_restapi_client.exceptions import ApiValueError
from papermerge_restapi_client.exceptions import ApiKeyError
from papermerge_restapi_client.exceptions import ApiException
